@@ -47,14 +47,6 @@ typedef unsigned long ulong;
 #endif
 #endif
 
-#if PY_VERSION_HEX < 0x02060000
-#if defined(MS_WINDOWS) || defined(PYOS_OS2)
-#define PyOS_stricmp stricmp
-#else
-#define PyOS_stricmp strcasecmp
-#endif
-#endif
-
 #define INITCHECK if (!self->is_initialised) {	PyErr_Format(PyExc_RuntimeError, "%s object not initialised!", self->ob_type->tp_name);	return NULL; }
 
 PyObject *module;
