@@ -4,7 +4,7 @@
 #include "liblzma.h"
 #include <structmember.h>
 
-#define CHECK_RANGE(x, a, b, msg) if (check_range(x, a, b)) { PyErr_Format(PyExc_ValueError, msg, a, b, (int32_t)x); RetVal = false; goto end; }
+#define CHECK_RANGE(x, a, b, msg) if (check_range(x, a, b)) { PyErr_Format(PyExc_ValueError, msg, a, b, (int32_t)x); ret = false; goto end; }
 static inline bool check_range(uint32_t x, uint32_t a, uint32_t b){
 	return (x < a || x > b);
 }
